@@ -9,10 +9,12 @@
 #include "settingsimpl_p.h"
 #include "spellerplugin_p.h"
 
-#include <QCache>
 #include "core_debug.h"
 
-namespace Sonnet {
+#include <QCache>
+
+namespace Sonnet
+{
 class SpellerPrivate
 {
 public:
@@ -30,10 +32,6 @@ public:
         settings = loader->settings();
 
         language = lang;
-
-        if (language.isEmpty()) {
-            language = settings->defaultLanguage();
-        }
         updateDict();
     }
 
@@ -48,7 +46,7 @@ public:
             recreateDict();
             settings->setModified(false);
         }
-        return dict;
+        return !dict.isNull();
     }
 
     void recreateDict()
@@ -240,7 +238,7 @@ bool Speller::testAttribute(Attribute attr) const
 
 bool Speller::isValid() const
 {
-    return d->dict;
+    return !d->dict.isNull();
 }
 
 void Speller::setLanguage(const QString &lang)
