@@ -1,20 +1,7 @@
 /*  This file is part of the KDE libraries
-    Copyright (c) 2006 Jacob R Rideout <kde@jacobrideout.net>
+    SPDX-FileCopyrightText: 2006 Jacob R Rideout <kde@jacobrideout.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef TEXTBREAKS_H
@@ -24,7 +11,8 @@ class QString;
 
 #include "sonnetcore_export.h"
 
-namespace Sonnet {
+namespace Sonnet
+{
 class TextBreaksPrivate;
 
 /**
@@ -32,7 +20,7 @@ class TextBreaksPrivate;
  *
  * TextBreaks is a class that determines the boundaries between graphemes
  * (characters as per the unicode definition,) words and sentences. The
- * default implementation conforms to Unicode Standard Annex #29 http://unicode.org/reports/tr29/.
+ * default implementation conforms to Unicode Standard Annex #29 https://unicode.org/reports/tr29/.
  * You can subclass TextBreaks to create the correct behaviour for languages that require it.
  *
  * @author Jacob Rideout <kde@jacobrideout.net>
@@ -41,7 +29,6 @@ class TextBreaksPrivate;
 class SONNETCORE_EXPORT TextBreaks
 {
 public:
-
     struct Position {
         int start, length;
     };
@@ -106,4 +93,7 @@ private:
     TextBreaksPrivate *const d;
 };
 }
+
+Q_DECLARE_TYPEINFO(Sonnet::TextBreaks::Position, Q_PRIMITIVE_TYPE);
+
 #endif
